# == Class: prometheusforemansd
#
# Installs and configures ForemanDNS server.
#
# === Parameters
# [*archive_source*]
# Download location of tarball to be used with the 'archive' install method.
# Defaults to the URL of the latest version of prometheusforemansd available at the time of module release.
#
# [*install_dir*]
# Installation directory to be used with the 'archive' install method.
# Defaults to '/usr/share/prometheusforemansd'.
#
# [*install_method*]
# Set to 'archive' to install prometheusforemansd using the tar archive.
# Defaults to 'archive'.
#
# [*service_name*]
# The name of the service managed with the 'archive' and 'package' install methods.
# Defaults to 'prometheusforemansd'.
#
# [*version*]
# The version of prometheusforemansd to install and manage.
# Defaults to the latest version of prometheusforemansd available at the time of module release.
#
# === Examples
#
#  class { '::prometheusforemansd':
#    version  => 'v1.0.0',
#  }
#
class prometheusforemansd (
  $archive_source      = $::prometheusforemansd::params::archive_source,
  $cfg_location        = $::prometheusforemansd::params::cfg_location,
  $cfg                 = $::prometheusforemansd::params::cfg,
  $install_dir         = $::prometheusforemansd::params::install_dir,
  $install_method      = $::prometheusforemansd::params::install_method,
  $service_name        = $::prometheusforemansd::params::service_name,
  $version             = $::prometheusforemansd::params::version
) inherits prometheusforemansd::params {

  # validate parameters here
  if !is_hash($cfg) {
    fail('cfg parameter must be a hash')
  }

  class { 'prometheusforemansd::install': } ->
  class { 'prometheusforemansd::config': } ~>
  class { 'prometheusforemansd::service': }

  contain 'prometheusforemansd::install'
  contain 'prometheusforemansd::service'

  #Class['prometheusforemansd']
}